@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 package App::grindperl;
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003';
 
 use autodie;
 use Getopt::Lucid ':all';
@@ -275,7 +275,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -283,13 +283,13 @@ App::grindperl - Guts of the grindperl tool
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
-   use App::grindperl;
-   my $app = App::grindperl->new;
-   exit $app->run;
+  use App::grindperl;
+  my $app = App::grindperl->new;
+  exit $app->run;
 
 =head1 DESCRIPTION
 
@@ -323,7 +323,7 @@ L<grindperl>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/dagolden/app-grindperl/issues>.
+at L<https://github.com/dagolden/App-grindperl/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -331,14 +331,20 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/dagolden/app-grindperl>
+L<https://github.com/dagolden/App-grindperl>
 
-  git clone git://github.com/dagolden/app-grindperl.git
+  git clone https://github.com/dagolden/App-grindperl.git
 
 =head1 AUTHOR
 
 David Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Sawyer X
+
+Sawyer X <xsawyerx@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2011 by David Golden.
